@@ -91,7 +91,7 @@ OptimizerSuccessiveHalving = R6Class("OptimizerSuccessiveHalving",
         param_classes = c("ParamLgl", "ParamInt", "ParamDbl", "ParamFct"),
         param_set = param_set,
         properties = c("dependencies", "single-crit", "multi-crit"),
-        packages = c("mlr3hyperband", "emoa"),
+        packages = "mlr3hyperband",
         label = "Successive Halving",
         man = "mlr3hyperband::mlr_optimizers_successive_halving"
       )
